@@ -360,14 +360,23 @@ def install_app(project_name, settings_path=None, **settings_patches):
         config.read(uwsgi_path)
     if not config.has_section('uwsgi'):
         config.add_section('uwsgi')
-        config.set('uwsgi', 'master', True)
-        config.set('uwsgi', 'enable-threads', True)
-        config.set('uwsgi', 'threads', 20)
-        config.set('uwsgi', 'processes', 4)
-        config.set('uwsgi', 'module', '%s.wsgi:application' % project_name)
-    config.set('uwsgi', 'socket', '127.0.0.1:%d' % uwsgi_port)
-    config.set('uwsgi', 'chdir', project_source_path(project_name))
-    config.set('uwsgi', 'home', project_venv_path(project_name))
+    optional_overrride_options = [
+        ('master', True),
+        ('enable-threads', True),
+        ('threads', 20),
+        ('processes', 4),
+        ('module', '%s.wsgi:application' % project_name),
+    ]
+    for key, value in optional_overrride_options:
+        if not config.has_option('uwsgi', key):
+            config.set('uwsgi', key, value)
+    must_override_options = [
+        ('socket', '127.0.0.1:%d' % uwsgi_port),
+        ('chdir', project_source_path(project_name)),
+        ('home', project_venv_path(project_name)),
+    ]
+    for key, value in must_override_options:
+        config.set('uwsgi', key, value)
     with hide('everything'):
         uid = local('id -u beanstalk', capture=True)
     config.set('uwsgi', 'uid', uid)
