@@ -1,24 +1,24 @@
 import os
 from fabric.api import *
+from fabric.colors import *
 from fabric.state import output as output_level
 from ground_soil.datastucture import SettingsDict
 from beanstalk import (BEANSTALK_ROOT_PATH, BEANSTALK_GLOBAL_BASE_PATH,
                        BEANSTALK_LOCAL_BASE_PATH)
-from beanstalk.console.titles import section_title
+from beanstalk.console.titles import section_title, separator, tool_title
 
 
-def load_role_settings(role=None, load_again=False, default_only=False,
+def load_role_settings(settings_role=None, load_again=False, default_only=False, debug=False,
                        additional_settings_path=None, **setting_patches):
     """Load beanstalk settings in
     """
     # Loaded?
     env_key = 'beanstalk_settings' if not default_only else 'beanstalk_default_settings'
-    if not load_again and env_key in env:
+    if not debug and not load_again and env_key in env:
         return env[env_key]
 
     # Check role
-    if role is None:
-        role = env.get('beanstalk_role', None)
+    role = settings_role or env.get('beanstalk_role', None)
     if role not in ('app', 'server'):
         abort('I don\'t know this role. ({role})'.format(role=role))
 
@@ -48,9 +48,30 @@ def load_role_settings(role=None, load_again=False, default_only=False,
             setting_paths.append(additional_settings_path)
 
     beanstalk_settings = SettingsDict(*setting_paths, **setting_patches)
+    if not debug:
+        env[env_key] = beanstalk_settings
+        return beanstalk_settings
+    else:
+        print tool_title('Beanstalk settings debug tool')
+        print 'yellow options which starts with * are overridden by next level.'
+        print separator('=')
+        # Print Settings dict in each level
+        settings_path_length = len(setting_paths)
+        last_settings_dict = {}
+        for i in xrange(1, settings_path_length + 1):
+            local_settings_dict = SettingsDict(*setting_paths[:i])
+            diff_items = [(key, local_settings_dict[key]) for key in local_settings_dict.keys()
+                          if (key not in last_settings_dict) or
+                             (key in last_settings_dict and last_settings_dict[key] != local_settings_dict[key])]
+            sorted_items = sorted(diff_items, cmp=lambda x, y: cmp(x[0], y[0]))
 
-    env[env_key] = beanstalk_settings
-    return beanstalk_settings
+            print cyan('Settings with {path}'.format(path=setting_paths[i - 1]))
+            for key, value in sorted_items:
+                output = '{0} = {1}'.format(key, value)
+                print output if value == beanstalk_settings[key] else yellow(' * ' + output)
+            print separator('-')
+
+            last_settings_dict = local_settings_dict
 
 
 def set_verbose_level(verbose_level=None):
